Debugger/DebugServer.py

changeset 6892
c147620313c5
parent 6888
e5f03f779b00
child 6894
df83ac87e0db
diff -r 93f82da09f22 -r c147620313c5 Debugger/DebugServer.py
--- a/Debugger/DebugServer.py	Thu Mar 21 19:27:42 2019 +0100
+++ b/Debugger/DebugServer.py	Fri Mar 22 19:11:11 2019 +0100
@@ -1313,7 +1313,8 @@
         self.debuggerInterface.remoteCompletion(text)
 
     def remoteUTPrepare(self, fn, tn, tfn, failed, cov, covname, coverase,
-                        clientType="", forProject=False, venvName=""):
+                        clientType="", forProject=False, venvName="",
+                        syspath=None):
         """
         Public method to prepare a new unittest run.
         
@@ -1338,8 +1339,11 @@
         @type bool
         @param venvName name of a virtual environment
         @type str
+        @param syspath list of directories to be added to sys.path on the
+            remote side
+        @type list of str
         """
-        if clientType not in self.getSupportedLanguages():
+        if clientType and clientType not in self.getSupportedLanguages():
             # a not supported client language was requested
             E5MessageBox.critical(
                 None,
@@ -1362,7 +1366,7 @@
         self.startClient(False, forProject=forProject, venvName=venvName)
         
         self.debuggerInterface.remoteUTPrepare(
             fn, tn, tfn, failed, cov, covname, coverase)
         self.debugging = False
         self.running = True
         
@@ -1362,7 +1366,7 @@
         
         self.debuggerInterface.remoteUTPrepare(
-            fn, tn, tfn, failed, cov, covname, coverase)
+            fn, tn, tfn, failed, cov, covname, coverase, syspath)
         self.debugging = False
         self.running = True

eric ide

mercurial